NLSL: cfs.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
cfs.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | cfs (a, b, n, z0, dz, nz, w, ideriv, phs, val)

## Function/Subroutine Documentation

subroutine cfs | ( | double complex, dimension(n) | a,
|  | double complex, dimension(n) | b,
|  | integer | n,
|  | double precision | z0,
|  | double precision | dz,
|  | integer | nz,
|  | double precision | w,
|  | integer | ideriv,
|  | double precision | phs,
|  | double precision, dimension(nz) | val
| ) |  |

Definition at line 43 of file cfs.f90.

Here is the caller graph for this function: